@@ -5,6 +5,7 @@ from typing import (
     Dict,
     Iterator,
     List,
+    Literal,
     MutableMapping,
     MutableSequence,
     Optional,
@@ -12,7 +13,6 @@ from typing import (
     Union,
     cast,
 )
-from typing_extensions import Literal
 
 from schema_salad.exceptions import ValidationException
 from schema_salad.sourceline import SourceLine, bullets, strip_dup_lineno
@@ -21,7 +21,7 @@ from schema_salad.utils import json_dumps
 from .errors import WorkflowException
 from .loghandler import _logger
 from .process import shortname
-from .utils import CWLObjectType, CWLOutputAtomType, CWLOutputType, SinkType, aslist
+from .utils import CWLObjectType, CWLOutputType, SinkType, aslist
 
 
 def _get_type(tp):
@@ -90,8 +90,8 @@ def can_assign_src_to_sink(src: SinkType, sink: Optional[SinkType], strict: bool
             return False
         if src["type"] == "array" and sink["type"] == "array":
             return can_assign_src_to_sink(
-                cast(MutableSequence[CWLOutputAtomType], src["items"]),
-                cast(MutableSequence[CWLOutputAtomType], sink["items"]),
+                cast(MutableSequence[CWLOutputType], src["items"]),
+                cast(MutableSequence[CWLOutputType], sink["items"]),
                 strict,
             )
         if src["type"] == "record" and sink["type"] == "record":
@@ -509,8 +509,7 @@ def get_step_id(field_id: str) -> str:
 
 
 def is_conditional_step(param_to_step: Dict[str, CWLObjectType], parm_id: str) -> bool:
-    source_step = param_to_step.get(parm_id)
-    if source_step is not None:
+    if (source_step := param_to_step.get(parm_id)) is not None:
         if source_step.get("when") is not None:
             return True
     return False
