@@ -12,12 +12,12 @@ from typing import (
     Dict,
     Iterable,
     List,
+    Literal,
     Optional,
     TextIO,
     Tuple,
     Union,
 )
-from typing_extensions import Literal
 
 from ruamel.yaml.comments import CommentedMap
 from schema_salad.avro.schema import Names
@@ -42,7 +42,7 @@ if TYPE_CHECKING:
 
 
 class ContextBase:
-    """Shared kwargs based initilizer for :py:class:`RuntimeContext` and :py:class:`LoadingContext`."""
+    """Shared kwargs based initializer for :py:class:`RuntimeContext` and :py:class:`LoadingContext`."""
 
     def __init__(self, kwargs: Optional[Dict[str, Any]] = None) -> None:
         """Initialize."""
@@ -197,6 +197,8 @@ class RuntimeContext(ContextBase):
         self.mpi_config: MpiConfig = MpiConfig()
         self.default_stdout: Optional[Union[IO[bytes], TextIO]] = None
         self.default_stderr: Optional[Union[IO[bytes], TextIO]] = None
+        self.validate_only: bool = False
+        self.validate_stdout: Optional[Union[IO[bytes], TextIO, IO[str]]] = None
         super().__init__(kwargs)
         if self.tmp_outdir_prefix == "":
             self.tmp_outdir_prefix = self.tmpdir_prefix
