@@ -16,9 +16,35 @@ def cuda_version_and_device_count() -> Tuple[str, int]:
         _logger.warning("Error checking CUDA version with nvidia-smi: %s", e)
         return ("", 0)
     dm = xml.dom.minidom.parseString(out)  # nosec
-    ag = dm.getElementsByTagName("attached_gpus")[0].firstChild
-    cv = dm.getElementsByTagName("cuda_version")[0].firstChild
-    return (cv.data, int(ag.data))
+
+    ag = dm.getElementsByTagName("attached_gpus")
+    if len(ag) < 1 or ag[0].firstChild is None:
+        _logger.warning(
+            "Error checking CUDA version with nvidia-smi. Missing 'attached_gpus' or it is empty.: %s",
+            out,
+        )
+        return ("", 0)
+    ag_element = ag[0].firstChild
+
+    cv = dm.getElementsByTagName("cuda_version")
+    if len(cv) < 1 or cv[0].firstChild is None:
+        _logger.warning(
+            "Error checking CUDA version with nvidia-smi. Missing 'cuda_version' or it is empty.: %s",
+            out,
+        )
+        return ("", 0)
+    cv_element = cv[0].firstChild
+
+    if isinstance(cv_element, xml.dom.minidom.Text) and isinstance(
+        ag_element, xml.dom.minidom.Text
+    ):
+        return (cv_element.data, int(ag_element.data))
+    _logger.warning(
+        "Error checking CUDA version with nvidia-smi. "
+        "Either 'attached_gpus' or 'cuda_version' was not a text node: %s",
+        out,
+    )
+    return ("", 0)
 
 
 def cuda_check(cuda_req: CWLObjectType, requestCount: int) -> int:
