@@ -11,6 +11,7 @@ _logger.setLevel(logging.INFO)
 
 def configure_logging(
     stderr_handler: logging.Handler,
+    no_warnings: bool,
     quiet: bool,
     debug: bool,
     enable_color: bool,
@@ -21,6 +22,12 @@ def configure_logging(
     rdflib_logger = logging.getLogger("rdflib.term")
     rdflib_logger.addHandler(stderr_handler)
     rdflib_logger.setLevel(logging.ERROR)
+    deps_logger = logging.getLogger("galaxy.tool_util.deps")
+    deps_logger.addHandler(stderr_handler)
+    ss_logger = logging.getLogger("salad")
+    ss_logger.addHandler(stderr_handler)
+    if no_warnings:
+        stderr_handler.setLevel(logging.ERROR)
     if quiet:
         # Silence STDERR, not an eventual provenance log file
         stderr_handler.setLevel(logging.WARN)
@@ -29,6 +36,7 @@ def configure_logging(
         base_logger.setLevel(logging.DEBUG)
         stderr_handler.setLevel(logging.DEBUG)
         rdflib_logger.setLevel(logging.DEBUG)
+        deps_logger.setLevel(logging.DEBUG)
     fmtclass = coloredlogs.ColoredFormatter if enable_color else logging.Formatter
     formatter = fmtclass("%(levelname)s %(message)s")
     if timestamps:
