@@ -21,17 +21,13 @@ def resolve_local(document_loader: Optional[Loader], uri: str) -> Optional[str]:
 
     if pathobj.is_file():
         if frag:
-            return "{}#{}".format(pathobj.as_uri(), frag)
+            return f"{pathobj.as_uri()}#{frag}"
         return pathobj.as_uri()
 
     sharepaths = [
-        os.environ.get(
-            "XDG_DATA_HOME", os.path.join(os.path.expanduser("~"), ".local", "share")
-        )
+        os.environ.get("XDG_DATA_HOME", os.path.join(os.path.expanduser("~"), ".local", "share"))
     ]
-    sharepaths.extend(
-        os.environ.get("XDG_DATA_DIRS", "/usr/local/share/:/usr/share/").split(":")
-    )
+    sharepaths.extend(os.environ.get("XDG_DATA_DIRS", "/usr/local/share/:/usr/share/").split(":"))
     shares = [os.path.join(s, "commonwl", uri) for s in sharepaths]
 
     _logger.debug("Search path is %s", shares)
@@ -39,8 +35,8 @@ def resolve_local(document_loader: Optional[Loader], uri: str) -> Optional[str]:
     for path in shares:
         if os.path.exists(path):
             return Path(uri).as_uri()
-        if os.path.exists("{}.cwl".format(path)):
-            return Path("{}.cwl".format(path)).as_uri()
+        if os.path.exists(f"{path}.cwl"):
+            return Path(f"{path}.cwl").as_uri()
     return None
 
 
@@ -53,15 +49,17 @@ def tool_resolver(document_loader: Loader, uri: str) -> Optional[str]:
 
 
 ga4gh_tool_registries = ["https://dockstore.org/api"]
-# in the TRS registry, a primary descriptor can be reached at {0}/api/ga4gh/v2/tools/{1}/versions/{2}/plain-CWL/descriptor
-# The primary descriptor is a CommandLineTool in the case that the files endpoint only describes one file
-# When the primary descriptor is a Workflow, files need to be imported without stripping off "descriptor", looking at the files endpoint is a workaround
+# in the TRS registry, a primary descriptor can be reached at
+# {0}/api/ga4gh/v2/tools/{1}/versions/{2}/plain-CWL/descriptor
+# The primary descriptor is a CommandLineTool in the case that the files
+# endpoint only describes one file
+# When the primary descriptor is a Workflow, files need to be imported without
+# stripping off "descriptor", looking at the files endpoint is a workaround
 # tested with TRS version 2.0.0-beta.2
-# TODO not stripping off "descriptor" when looking for local imports would also work https://github.com/ga4gh/tool-registry-service-schemas/blob/2.0.0-beta.2/src/main/resources/swagger/ga4gh-tool-discovery.yaml#L273
+# TODO not stripping off "descriptor" when looking for local imports would also
+# work https://github.com/ga4gh/tool-registry-service-schemas/blob/2.0.0-beta.2/src/main/resources/swagger/ga4gh-tool-discovery.yaml#L273  # noqa: B950
 GA4GH_TRS_FILES = "{0}/api/ga4gh/v2/tools/{1}/versions/{2}/CWL/files"
-GA4GH_TRS_PRIMARY_DESCRIPTOR = (
-    "{0}/api/ga4gh/v2/tools/{1}/versions/{2}/plain-CWL/descriptor/{3}"
-)
+GA4GH_TRS_PRIMARY_DESCRIPTOR = "{0}/api/ga4gh/v2/tools/{1}/versions/{2}/plain-CWL/descriptor/{3}"
 
 
 def resolve_ga4gh_tool(document_loader: Loader, uri: str) -> Optional[str]:
