@@ -10,9 +10,13 @@ from subprocess import check_call, check_output  # nosec
 from typing import Callable, Dict, List, MutableMapping, Optional, Tuple, cast
 
 from schema_salad.sourceline import SourceLine
+from spython.main import Client
+from spython.main.parse.parsers.docker import DockerParser
+from spython.main.parse.writers.singularity import SingularityWriter
 
 from .builder import Builder
 from .context import RuntimeContext
+from .docker import DockerCommandLineJob
 from .errors import WorkflowException
 from .job import ContainerCommandLineJob
 from .loghandler import _logger
@@ -106,6 +110,14 @@ def is_version_3_4_or_newer() -> bool:
     return v[0][0] >= 4 or (v[0][0] == 3 and v[0][1] >= 4)
 
 
+def is_version_3_9_or_newer() -> bool:
+    """Detect if Singularity v3.9+ is available."""
+    if is_apptainer_1_or_newer():
+        return True  # this is equivalent to singularity-ce > 3.9.5
+    v = get_version()
+    return v[0][0] >= 4 or (v[0][0] == 3 and v[0][1] >= 9)
+
+
 def _normalize_image_id(string: str) -> str:
     return string.replace("/", "_") + ".img"
 
@@ -131,6 +143,7 @@ class SingularityCommandLineJob(ContainerCommandLineJob):
     def get_image(
         dockerRequirement: Dict[str, str],
         pull_image: bool,
+        tmp_outdir_prefix: str,
         force_pull: bool = False,
     ) -> bool:
         """
@@ -153,7 +166,50 @@ class SingularityCommandLineJob(ContainerCommandLineJob):
         elif is_version_2_6() and "SINGULARITY_PULLFOLDER" in os.environ:
             cache_folder = os.environ["SINGULARITY_PULLFOLDER"]
 
-        if "dockerImageId" not in dockerRequirement and "dockerPull" in dockerRequirement:
+        if "dockerFile" in dockerRequirement:
+            if cache_folder is None:  # if environment variables were not set
+                cache_folder = create_tmp_dir(tmp_outdir_prefix)
+
+            absolute_path = os.path.abspath(cache_folder)
+            if "dockerImageId" in dockerRequirement:
+                image_name = dockerRequirement["dockerImageId"]
+                image_path = os.path.join(absolute_path, image_name)
+                if os.path.exists(image_path):
+                    found = True
+            if found is False:
+                dockerfile_path = os.path.join(absolute_path, "Dockerfile")
+                singularityfile_path = dockerfile_path + ".def"
+                # if you do not set APPTAINER_TMPDIR will crash
+                # WARNING: 'nodev' mount option set on /tmp, it could be a
+                #          source of failure during build process
+                # FATAL:   Unable to create build: 'noexec' mount option set on
+                #          /tmp, temporary root filesystem won't be usable at this location
+                with open(dockerfile_path, "w") as dfile:
+                    dfile.write(dockerRequirement["dockerFile"])
+
+                singularityfile = SingularityWriter(DockerParser(dockerfile_path).parse()).convert()
+                with open(singularityfile_path, "w") as file:
+                    file.write(singularityfile)
+
+                os.environ["APPTAINER_TMPDIR"] = absolute_path
+                singularity_options = ["--fakeroot"] if not shutil.which("proot") else []
+                if "dockerImageId" in dockerRequirement:
+                    Client.build(
+                        recipe=singularityfile_path,
+                        build_folder=absolute_path,
+                        image=dockerRequirement["dockerImageId"],
+                        sudo=False,
+                        options=singularity_options,
+                    )
+                else:
+                    Client.build(
+                        recipe=singularityfile_path,
+                        build_folder=absolute_path,
+                        sudo=False,
+                        options=singularity_options,
+                    )
+                found = True
+        elif "dockerImageId" not in dockerRequirement and "dockerPull" in dockerRequirement:
             match = re.search(pattern=r"([a-z]*://)", string=dockerRequirement["dockerPull"])
             img_name = _normalize_image_id(dockerRequirement["dockerPull"])
             candidates.append(img_name)
@@ -234,13 +290,6 @@ class SingularityCommandLineJob(ContainerCommandLineJob):
                     check_call(cmd, stdout=sys.stderr)  # nosec
                     found = True
 
-            elif "dockerFile" in dockerRequirement:
-                raise SourceLine(
-                    dockerRequirement, "dockerFile", WorkflowException, debug
-                ).makeError(
-                    "dockerFile is not currently supported when using the "
-                    "Singularity runtime for Docker containers."
-                )
             elif "dockerLoad" in dockerRequirement:
                 if is_version_3_1_or_newer():
                     if "dockerImageId" in dockerRequirement:
@@ -289,21 +338,30 @@ class SingularityCommandLineJob(ContainerCommandLineJob):
         if not bool(shutil.which("singularity")):
             raise WorkflowException("singularity executable is not available")
 
-        if not self.get_image(cast(Dict[str, str], r), pull_image, force_pull):
+        if not self.get_image(cast(Dict[str, str], r), pull_image, tmp_outdir_prefix, force_pull):
             raise WorkflowException("Container image {} not found".format(r["dockerImageId"]))
 
-        return os.path.abspath(cast(str, r["dockerImageId"]))
+        if "CWL_SINGULARITY_CACHE" in os.environ:
+            cache_folder = os.environ["CWL_SINGULARITY_CACHE"]
+            img_path = os.path.join(cache_folder, cast(str, r["dockerImageId"]))
+        else:
+            img_path = cast(str, r["dockerImageId"])
+
+        return os.path.abspath(img_path)
 
     @staticmethod
     def append_volume(runtime: List[str], source: str, target: str, writable: bool = False) -> None:
         """Add binding arguments to the runtime list."""
-        runtime.append("--bind")
-        # Mounts are writable by default, so 'rw' is optional and not
-        # supported (due to a bug) in some 3.6 series releases.
-        vol = f"{source}:{target}"
-        if not writable:
-            vol += ":ro"
-        runtime.append(vol)
+        if is_version_3_9_or_newer():
+            DockerCommandLineJob.append_volume(runtime, source, target, writable, skip_mkdirs=True)
+        else:
+            runtime.append("--bind")
+            # Mounts are writable by default, so 'rw' is optional and not
+            # supported (due to a bug) in some 3.6 series releases.
+            vol = f"{source}:{target}"
+            if not writable:
+                vol += ":ro"
+            runtime.append(vol)
 
     def add_file_or_directory_volume(
         self, runtime: List[str], volume: MapperEnt, host_outdir_tgt: Optional[str]
