@@ -17,19 +17,20 @@ from typing import (
 )
 from uuid import UUID
 
+from mypy_extensions import mypyc_attr
+from ruamel.yaml.comments import CommentedMap
 from schema_salad.exceptions import ValidationException
 from schema_salad.sourceline import SourceLine, indent
 
-from ruamel.yaml.comments import CommentedMap
-
 from . import command_line_tool, context, procgenerator
 from .checker import circular_dependency_checker, loop_checker, static_checker
 from .context import LoadingContext, RuntimeContext, getdefault
+from .cwlprov.provenance_profile import ProvenanceProfile
+from .cwlprov.writablebagfile import create_job
 from .errors import WorkflowException
 from .load_tool import load_tool
 from .loghandler import _logger
 from .process import Process, get_overrides, shortname
-from .provenance_profile import ProvenanceProfile
 from .utils import (
     CWLObjectType,
     CWLOutputType,
@@ -42,7 +43,7 @@ from .workflow_job import WorkflowJob
 
 
 def default_make_tool(toolpath_object: CommentedMap, loadingContext: LoadingContext) -> Process:
-    """Instatiate the given CWL Process."""
+    """Instantiate the given CWL Process."""
     if not isinstance(toolpath_object, MutableMapping):
         raise WorkflowException("Not a dict: '%s'" % toolpath_object)
     if "class" in toolpath_object:
@@ -66,6 +67,7 @@ def default_make_tool(toolpath_object: CommentedMap, loadingContext: LoadingCont
 context.default_make_tool = default_make_tool
 
 
+@mypyc_attr(serializable=True)
 class Workflow(Process):
     def __init__(
         self,
@@ -163,7 +165,7 @@ class Workflow(Process):
             if runtimeContext.toplevel:
                 # Record primary-job.json
                 runtimeContext.research_obj.fsaccess = runtimeContext.make_fs_access("")
-                runtimeContext.research_obj.create_job(builder.job)
+                create_job(runtimeContext.research_obj, builder.job)
 
         job = WorkflowJob(self, runtimeContext)
         yield job
